==> hudi-0.11.0.src.tgz: hudi-0.11.0/hudi-client/hudi-flink-client/src/main/java/org/apache/hudi/io/MiniBatchHandle.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hudi.io;

import org.apache.hadoop.fs.Path;

/**
 * Hoodie write handle that supports write as mini-batch.
 */
public interface MiniBatchHandle {

  /**
   * Finalize the write of one mini-batch. Usually these mini-bathes
   * come from one checkpoint interval. The file handle may roll over to new name
   * if the name conflicts, give a chance to clean the intermediate file.
   */
  default void finalizeWrite() {}

  /**
   * Close the file handle gracefully, if any error happens during the file handle close,
   * clean the file to not left corrupted file.
   */
  void closeGracefully();

  /**
   * Returns the write file path.
   */
  Path getWritePath();

  /**
   * Whether the old write file should be replaced with the same name new file
   * using content merged with incremental new data batch.
   */
  default boolean shouldReplace() {
    return true;
  }
}

==> hudi-0.12.2.src.tgz: hudi-0.12.2/hudi-client/hudi-flink-client/src/main/java/org/apache/hudi/io/MiniBatchHandle.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hudi.io;

import org.apache.hadoop.fs.Path;

/**
 * Hoodie write handle that supports write as mini-batch.
 */
public interface MiniBatchHandle {

  /**
   * Finalize the write of one mini-batch. Usually these mini-bathes
   * come from one checkpoint interval. The file handle may roll over to new name
   * if the name conflicts, give a chance to clean the intermediate file.
   */
  default void finalizeWrite() {
  }

  /**
   * Close the file handle gracefully, if any error happens during the file handle close,
   * clean the file to not left corrupted file.
   */
  void closeGracefully();

  /**
   * Returns the write file path.
   */
  Path getWritePath();

  /**
   * Whether the old write file should be replaced with the same name new file
   * using content merged with incremental new data batch.
   */
  default boolean shouldReplace() {
    return true;
  }
}
